import java.io.File;
import java.util.ArrayList;
import java.util.Random;
import java.util.Scanner;

import javax.swing.JFileChooser;
import javax.swing.filechooser.FileNameExtensionFilter;

/**
 * A class that runs a simulation of the SpacePort program. Acts as a "tester"
 * @author Joel
 * @version Sp 2013
 */
public class SpacePortSimulation
{
	//main method for running the simulation. You can modify the which port used for the simuation here
	public static void main(String[] args)
	{
		ShipHasher hasher = null; //SET UP THE HASHER TO USE
		SpacePort<String, SpaceShipValet> port = null; //SET UP THE PORT HERE
		
		SpacePortSimulation sim = new SpacePortSimulation(new SpacePortAuthority(port)); //make the sim
		sim.runSimulation(100); //run the sim for the given number of "events"
	}
	
	
	//instance variable for the simulation
	private ArrayList<SpaceShip> ships;
	private SpacePortAuthority spa;
	
	/**
	 * Makes a new simulation for the given Authority (which controls a particular port)
	 */
	public SpacePortSimulation(SpacePortAuthority spa)
	{
		ships = loadShipsFromFile("ships.txt");
		this.spa = spa;
	}
	
	/**
	 * Runs the simulation for the given number of events (either a ship trying to arrive or trying to leave).
	 * Note that this simulation is pretty dumb: random ships try to arrive or leave, with no indication of whether
	 * They were in the dock in the first place. Feel free to modify this and make it more sensible!
	 */
	public void runSimulation(int numTests)
	{
        Random r = new Random();

        for(int i=0; i<numTests; i++)
        {
        	SpaceShip s = ships.get(r.nextInt(ships.size()));
        	boolean comingIn = r.nextBoolean();
        	boolean success = false;
        	if(comingIn)
        	{
        		System.out.print("Checking in " + s.getLicense() +  " carrying " + s.getCargo() + " ... ");
                success = spa.checkIn(s);
        	}
        	else //goingOut
        	{
        		System.out.print("Checking out " + s.getLicense() + " ... ");
                success = spa.checkOut(s);
        	}
                
            if (!success)
            {
                System.out.println(" Operation Failed. Intergalactic enforcement has been notified.");
            }
            else
            {
                System.out.println(" Done. ");
            }
        }
        
        System.out.println();
        System.out.println(spa.budgetReport());
	}
	
	/**
	 * Helper method to load a list of ships from a file. Ship files have a new ship on each line, with a comma separating
	 * the license and the cargo.
	 * NOTE: You can use your random sentence generator to make longer or more interesting lists of ships!
	 * @param filename The file to load
	 * @return An ArrayList of ships
	 */
	public ArrayList<SpaceShip> loadShipsFromFile(String filename)
	{
		File f = null;
		if(filename != null)
			f = new File(filename);
		else
		{
			JFileChooser chooser = new JFileChooser(); //a file chooser
			chooser.setFileFilter(new FileNameExtensionFilter("Text files", "txt")); //for txt files
			int returnVal = chooser.showOpenDialog(chooser); //show the dialog to OPEN
			if(returnVal == JFileChooser.APPROVE_OPTION) //if they picked something
				f = chooser.getSelectedFile();
		}

		if(f != null)
		{
			ArrayList<SpaceShip> ships = new ArrayList<SpaceShip>();
			try {
				Scanner sc = new Scanner(f); //parse it with Scanner
				while(sc.hasNextLine())
				{
					String line = sc.nextLine();
					String[] parts = line.split(",");
					ships.add(new SpaceShip(parts[0],parts[1]));
				}
				sc.close();
				return ships;
			}
			catch(Exception e) {
				System.out.println("Error loading from file: "+e);
				e.printStackTrace();
			}
		}		
		
		return null;
	}
	
}
